@@ -4,7 +4,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Control.Exception
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -30,6 +30,9 @@ module TextShow.Control.Exception (
   , showbBlockedIndefinitelyOnSTM
 #if MIN_VERSION_base(4,8,0)
   , showbAllocationLimitExceeded
+#endif
+#if MIN_VERSION_base(4,9,0)
+  , showbTypeError
 #endif
   , showbDeadlock
   , showbNoMethodError
@@ -52,7 +55,7 @@ import Data.Text.Lazy.Builder (singleton)
 import Prelude ()
 import Prelude.Compat
 
-import TextShow.Classes (TextShow(showb, showbPrec))
+import TextShow.Classes (TextShow(..))
 import TextShow.FromStringTextShow (FromStringShow(..))
 import TextShow.TH.Internal (deriveTextShow)
 
@@ -164,6 +167,16 @@ showbAllocationLimitExceeded AllocationLimitExceeded = "allocation limit exceede
 {-# INLINE showbAllocationLimitExceeded #-}
 #endif
 
+#if MIN_VERSION_base(4,9,0)
+-- | Convert a 'TypeError' to a 'Builder'.
+-- This function is only available with @base-4.9.0.0@ or later.
+--
+-- /Since: 3/
+showbTypeError :: TypeError -> Builder
+showbTypeError (TypeError err) = fromString err
+{-# INLINE showbTypeError #-}
+#endif
+
 -- | Convert a 'Deadlock' exception to a 'Builder'.
 --
 -- /Since: 2/
@@ -210,10 +223,12 @@ showbRecUpdError (RecUpdError err) = fromString err
 --
 -- /Since: 2/
 showbErrorCall :: ErrorCall -> Builder
-showbErrorCall (ErrorCall err) = fromString err
 #if MIN_VERSION_base(4,9,0)
+showbErrorCall (ErrorCallWithLocation err "")  = fromString err
 showbErrorCall (ErrorCallWithLocation err loc) =
   fromString err <> singleton '\n' <> fromString loc
+#else
+showbErrorCall (ErrorCall err) = fromString err
 #endif
 
 -- | Convert a 'MaskingState' to a 'Builder'.
@@ -275,6 +290,12 @@ instance TextShow AllocationLimitExceeded where
     {-# INLINE showb #-}
 #endif
 
+#if MIN_VERSION_base(4,9,0)
+instance TextShow TypeError where
+    showb = showbTypeError
+    {-# INLINE showb #-}
+#endif
+
 instance TextShow Deadlock where
     showb = showbDeadlock
     INLINE_INST_FUN(showb)
