@@ -3,7 +3,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.Dynamic
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -21,7 +21,7 @@ import Data.Text.Lazy.Builder (Builder)
 
 import Prelude ()
 
-import TextShow.Classes (TextShow(showb))
+import TextShow.Classes (TextShow(..))
 import TextShow.Data.Typeable (showbTypeRepPrec)
 
 #include "inline.h"
