@@ -2,17 +2,17 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.List
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
 Portability: GHC
 
-Exports 'showbListWith'.
+Exports 'showbListWith', 'showtListWith', and 'showtlListWith'.
 -}
-module TextShow.Data.List (showbListWith) where
+module TextShow.Data.List (showbListWith, showtListWith, showtlListWith) where
 
-import TextShow.Classes (TextShow(showb, showbList), TextShow1(..), showbListWith)
+import TextShow.Classes (TextShow(..), TextShow1(..), showbListWith, showtListWith, showtlListWith)
 import TextShow.Data.Char ()
 import TextShow.Data.Integral ()
 
@@ -26,5 +26,5 @@ instance TextShow a => TextShow [a] where
     INLINE_INST_FUN(showb)
 
 instance TextShow1 [] where
-    showbPrecWith sp _ = showbListWith (sp 0)
-    INLINE_INST_FUN(showbPrecWith)
+    liftShowbPrec _ sl _ = sl
+    INLINE_INST_FUN(liftShowbPrec)
