@@ -10,7 +10,7 @@
 
 {-|
 Module:      TextShow.Data.Proxy
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -25,8 +25,9 @@ module TextShow.Data.Proxy (showbProxy) where
 import Data.Proxy (Proxy(..))
 import Data.Text.Lazy.Builder (Builder)
 
-import TextShow.Classes (TextShow(showb, showbPrec))
-import TextShow.TH.Internal (deriveTextShow1, makeShowbPrec)
+import TextShow.Classes (TextShow(..))
+import TextShow.TH.Internal (deriveTextShow1, makeShowbPrec,
+                             makeShowtPrec, makeShowtlPrec)
 
 #include "inline.h"
 
@@ -38,7 +39,11 @@ showbProxy = showb
 {-# INLINE showbProxy #-}
 
 instance TextShow (Proxy s) where
-    showbPrec = $(makeShowbPrec ''Proxy)
+    showbPrec  = $(makeShowbPrec  ''Proxy)
+    showtPrec  = $(makeShowtPrec  ''Proxy)
+    showtlPrec = $(makeShowtlPrec ''Proxy)
     INLINE_INST_FUN(showbPrec)
+    INLINE_INST_FUN(showtPrec)
+    INLINE_INST_FUN(showtlPrec)
 
 $(deriveTextShow1 ''Proxy)
