@@ -8,7 +8,7 @@
 #endif
 {-|
 Module:      TextShow.Data.Type.Coercion
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -29,8 +29,8 @@ module TextShow.Data.Type.Coercion (
 import Data.Text.Lazy.Builder (Builder)
 import Data.Type.Coercion (Coercion(..))
 
-import TextShow.Classes (TextShow(showb, showbPrec), TextShow1(..))
-import TextShow.TH.Internal (deriveTextShow2, makeShowbPrec, makeShowbPrecWith)
+import TextShow.Classes (TextShow(..), TextShow1(..))
+import TextShow.TH.Internal (deriveTextShow, deriveTextShow2, makeLiftShowbPrec)
 
 -- | Convert a representational equality value to a 'Builder'.
 -- This function is only available with @base-4.7.0.0@ or later.
@@ -40,13 +40,10 @@ showbCoercion :: Coercion a b -> Builder
 showbCoercion = showb
 {-# INLINE showbCoercion #-}
 
-instance TextShow (Coercion a b) where
-    showbPrec = $(makeShowbPrec ''Coercion)
-    {-# INLINE showbPrec #-}
+$(deriveTextShow ''Coercion)
 
 instance TextShow1 (Coercion a) where
-    showbPrecWith = $(makeShowbPrecWith ''Coercion)
-    {-# INLINE showbPrecWith #-}
+    liftShowbPrec = $(makeLiftShowbPrec ''Coercion)
 
 $(deriveTextShow2 ''Coercion)
 #endif
