@@ -9,7 +9,7 @@
 #endif
 {-|
 Module:      TextShow.Data.Type.Equality
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -30,8 +30,8 @@ module TextShow.Data.Type.Equality (
 import Data.Text.Lazy.Builder (Builder)
 import Data.Type.Equality ((:~:)(..))
 
-import TextShow.Classes (TextShow(showb, showbPrec), TextShow1(..))
-import TextShow.TH.Internal (deriveTextShow2, makeShowbPrec, makeShowbPrecWith)
+import TextShow.Classes (TextShow(..), TextShow1(..))
+import TextShow.TH.Internal (deriveTextShow, deriveTextShow2, makeLiftShowbPrec)
 
 -- | Convert a propositional equality value to a 'Builder'.
 -- This function is only available with @base-4.7.0.0@ or later.
@@ -41,13 +41,10 @@ showbPropEquality :: (a :~: b) -> Builder
 showbPropEquality = showb
 {-# INLINE showbPropEquality #-}
 
-instance TextShow (a :~: b) where
-    showbPrec = $(makeShowbPrec ''(:~:))
-    {-# INLINE showbPrec #-}
+$(deriveTextShow ''(:~:))
 
 instance TextShow1 ((:~:) a) where
-    showbPrecWith = $(makeShowbPrecWith ''(:~:))
-    {-# INLINE showbPrecWith #-}
+    liftShowbPrec = $(makeLiftShowbPrec ''(:~:))
 
 $(deriveTextShow2 ''(:~:))
 #endif
