@@ -1,6 +1,6 @@
 {-|
 Module:      TextShow.Data.Typeable.Utils
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -16,7 +16,7 @@ import Data.Text.Lazy.Builder (Builder, singleton)
 import Prelude ()
 import Prelude.Compat
 
-import TextShow.Classes (TextShow(showbPrec))
+import TextShow.Classes (TextShow(..))
 
 -- | Helper function for showing a list of arguments, each separated by the given
 -- 'Builder'.
