@@ -1,7 +1,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Data.Void
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -18,7 +18,7 @@ import Data.Void (Void, absurd)
 
 import Prelude ()
 
-import TextShow.Classes (TextShow(showb))
+import TextShow.Classes (TextShow(..))
 
 -- | Since 'Void' values logically don't exist, attempting to convert one to a
 -- 'Builder' will never terminate.
