@@ -5,7 +5,7 @@
 #endif
 {-|
 Module:      TextShow.GHC.Fingerprint
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -24,14 +24,15 @@ module TextShow.GHC.Fingerprint (
     ) where
 
 import Data.Monoid.Compat ((<>))
+import Data.Semigroup (mtimesDefault)
 import Data.Text.Lazy.Builder (Builder, singleton)
 import Data.Word (Word64)
 
 import GHC.Fingerprint.Type (Fingerprint(..))
 
-import TextShow.Classes (TextShow(showb))
+import TextShow.Classes (TextShow(..))
 import TextShow.Data.Integral (showbHex)
-import TextShow.Utils (lengthB, mtimesDefault)
+import TextShow.Utils (lengthB)
 
 -- | Convert a 'Fingerprint' to a 'Builder'.
 -- This function is only available with @base-4.4.0.0@ or later.
