@@ -5,7 +5,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 {-|
 Module:      TextShow.Numeric.Natural
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -29,7 +29,7 @@ import TextShow.Data.Integral (showbWord)
 import Numeric.Natural (Natural)
 #endif
 
-import TextShow.Classes (TextShow(showbPrec))
+import TextShow.Classes (TextShow(..))
 import TextShow.Data.Integral (showbIntegerPrec)
 
 #include "inline.h"
