@@ -1,6 +1,9 @@
+{-# LANGUAGE TemplateHaskell #-}
+{-# OPTIONS_GHC -fno-warn-orphans #-}
+
 {-|
 Module:      TextShow.TH
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -16,3 +19,8 @@ module TextShow.TH (module TextShow.TH.Internal) where
 
 import TextShow.Instances ()
 import TextShow.TH.Internal
+
+-------------------------------------------------------------------------------
+
+$(deriveTextShow ''Options)
+$(deriveTextShow ''GenTextMethods)
