@@ -1,6 +1,7 @@
 {-# LANGUAGE CPP                        #-}
 {-# LANGUAGE FlexibleInstances          #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
+{-# LANGUAGE KindSignatures             #-}
 {-# LANGUAGE MultiParamTypeClasses      #-}
 {-# LANGUAGE TemplateHaskell            #-}
 {-# LANGUAGE TypeFamilies               #-}
@@ -9,6 +10,11 @@
 {-# LANGUAGE DeriveGeneric              #-}
 #endif
 
+#if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE DataKinds                  #-}
+{-# LANGUAGE PolyKinds                  #-}
+#endif
+
 #if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
 -- Starting with GHC 7.10, NullaryTypeClasses was deprecated in favor of
 -- MultiParamTypeClasses, which is already enabled
@@ -17,7 +23,7 @@
 
 {-|
 Module:      Derived.DataFamilies
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -27,6 +33,9 @@ Defines corner case-provoking data families.
 -}
 module Derived.DataFamilies (
       NotAllShow(..)
+#if __GLASGOW_HASKELL__ >= 706
+    , KindDistinguished(..)
+#endif
 #if __GLASGOW_HASKELL__ >= 708
     , NullaryClass(..)
     , NullaryData(..)
@@ -45,7 +54,6 @@ import           GHC.Generics (Generic)
 import           GHC.Generics (Generic1)
 # endif
 #endif
-import           GHC.Show (appPrec, appPrec1, showSpace)
 
 import           Prelude ()
 import           Prelude.Compat
@@ -53,19 +61,17 @@ import           Prelude.Compat
 import           Test.QuickCheck (Arbitrary(..), oneof)
 
 #if MIN_VERSION_template_haskell(2,7,0)
+import           Text.Show.Deriving (deriveShow1)
 import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
-#endif
 
-import TransformersCompat (Show1(..), Show2(..))
+# if defined(NEW_FUNCTOR_CLASSES)
+import           Text.Show.Deriving (deriveShow2)
+# endif
+#endif
 
 -------------------------------------------------------------------------------
 
-data family NotAllShow
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-    a b c d :: *
-#else
-    w x y z :: *
-#endif
+data family NotAllShow (w :: *) (x :: *) (y :: *) (z :: *) :: *
 
 data instance NotAllShow ()  ()  () d = NASNoShow
 data instance NotAllShow Int b   c  d = NASShow1 c b
@@ -84,18 +90,14 @@ instance (Arbitrary b, Arbitrary c, Arbitrary d) => Arbitrary (NotAllShow Int b
                       , NASShow2 <$> arbitrary
                       ]
 
-instance (Show b, Show c) => Show1 (NotAllShow Int b c) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show b => Show2 (NotAllShow Int b) where
-    showsPrecWith2 sp1 _ p (NASShow1 c b) = showParen (p > appPrec) $
-          showString "NASShow1 "
-        . sp1 appPrec1 c . showSpace
-        . showsPrec appPrec1 b
-    showsPrecWith2 _ sp2 p (NASShow2 d) = showParen (p > appPrec) $
-          showString "NASShow2 "
-        . sp2 appPrec1 d
-
 #if MIN_VERSION_template_haskell(2,7,0)
+# if !defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow1 'NASShow1)
+# else
+$(deriveShow1 'NASShow1)
+$(deriveShow2 'NASShow2)
+# endif
+
 $(deriveTextShow  'NASShow1)
 $(deriveTextShow1 'NASShow2)
 $(deriveTextShow2 'NASShow1)
@@ -112,6 +114,61 @@ $(Generics.deriveRepresentable0 'NASShow1)
 
 -------------------------------------------------------------------------------
 
+#if __GLASGOW_HASKELL__ >= 706
+data family KindDistinguished (x :: k) (y :: *) (z :: *) :: *
+
+data instance KindDistinguished (a :: ()) b c = KindDistinguishedUnit b c
+  deriving ( Show
+           , Generic
+# if defined(__LANGUAGE_DERIVE_GENERIC1__)
+           , Generic1
+# endif
+           )
+
+data instance KindDistinguished (a :: Bool) b c = KindDistinguishedBool b c
+  deriving ( Show
+           , Generic
+# if defined(__LANGUAGE_DERIVE_GENERIC1__)
+           , Generic1
+# endif
+           )
+
+instance (Arbitrary b, Arbitrary c)
+      => Arbitrary (KindDistinguished (a :: ()) b c) where
+    arbitrary = KindDistinguishedUnit <$> arbitrary <*> arbitrary
+
+instance (Arbitrary b, Arbitrary c)
+      => Arbitrary (KindDistinguished (a :: Bool) b c) where
+    arbitrary = KindDistinguishedBool <$> arbitrary <*> arbitrary
+
+# if !defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow1 'KindDistinguishedUnit)
+
+$(deriveShow1 'KindDistinguishedBool)
+# else
+$(deriveShow1 'KindDistinguishedUnit)
+$(deriveShow2 'KindDistinguishedUnit)
+
+$(deriveShow1 'KindDistinguishedBool)
+$(deriveShow2 'KindDistinguishedBool)
+# endif
+
+$(deriveTextShow  'KindDistinguishedUnit)
+$(deriveTextShow1 'KindDistinguishedUnit)
+$(deriveTextShow2 'KindDistinguishedUnit)
+
+$(deriveTextShow  'KindDistinguishedBool)
+$(deriveTextShow1 'KindDistinguishedBool)
+$(deriveTextShow2 'KindDistinguishedBool)
+
+# if !defined(__LANGUAGE_DERIVE_GENERIC1__)
+$(Generics.deriveAll1 'KindDistinguishedUnit)
+$(Generics.deriveAll1 'KindDistinguishedBool)
+# endif
+#endif
+
+-------------------------------------------------------------------------------
+
 #if __GLASGOW_HASKELL__ >= 708
 class NullaryClass where
     data NullaryData :: *
@@ -121,8 +178,4 @@ instance NullaryClass where
       deriving (Arbitrary, Show, Generic)
 
 $(deriveTextShow 'NullaryCon)
-
-# if __GLASGOW_HASKELL__ < 706
-$(Generics.deriveAll 'NullaryCon)
-# endif
 #endif
