@@ -8,9 +8,13 @@
 {-# LANGUAGE DeriveGeneric     #-}
 #endif
 
+#if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE DataKinds         #-}
+#endif
+
 {-|
 Module:      Derived.Infix
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -37,25 +41,29 @@ import           GHC.Generics (Generic)
 import           GHC.Generics (Generic1)
 # endif
 #endif
-import           GHC.Show (appPrec, appPrec1, showSpace)
 
 import           Prelude ()
 import           Prelude.Compat
 
 import           Test.QuickCheck (Arbitrary(..), oneof)
 
-import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
+import           Text.Show.Deriving (deriveShow1)
+#if defined(NEW_FUNCTOR_CLASSES)
+import           Text.Show.Deriving (deriveShow2)
+#endif
 
-import           TransformersCompat (Show1(..), Show2(..), showsBinaryWith)
+import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
 
 -------------------------------------------------------------------------------
 
 infixl 3 :!:
 infix  4 :@:
 infixr 5 `TyConPlain`
+infixr 6 `TyConFakeInfix`
 data TyConPlain a b = (:!:) a b
                     | a :@: b
                     | a `TyConPlain` b
+                    | TyConFakeInfix a b
   deriving ( Show
 #if __GLASGOW_HASKELL__ >= 702
            , Generic
@@ -82,19 +90,16 @@ data TyConGADT a b where
 
 -------------------------------------------------------------------------------
 
-data family TyFamilyPlain
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-                          a b :: *
-#else
-                          y z :: *
-#endif
+data family TyFamilyPlain y z :: *
 
 infixl 3 :#:
 infix  4 :$:
 infixr 5 `TyFamilyPlain`
+infixr 6 `TyFamilyFakeInfix`
 data instance TyFamilyPlain a b = (:#:) a b
                                 | a :$: b
                                 | a `TyFamilyPlain` b
+                                | TyFamilyFakeInfix a b
   deriving ( Show
 #if __GLASGOW_HASKELL__ >= 706
            , Generic
@@ -106,12 +111,7 @@ data instance TyFamilyPlain a b = (:#:) a b
 
 -------------------------------------------------------------------------------
 
-data family TyFamilyGADT
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-                         a b :: *
-#else
-                         y z :: *
-#endif
+data family TyFamilyGADT y z :: *
 
 infixr 1 :*, :***, :****
 data instance TyFamilyGADT a b where
@@ -154,66 +154,12 @@ instance (Arbitrary a, Arbitrary b) => Arbitrary (TyFamilyGADT a b) where
 
 -------------------------------------------------------------------------------
 
-instance Show a => Show1 (TyConPlain a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyConPlain where
-    showsPrecWith2 sp1 sp2 p (a :!: b) =
-        showsBinaryWith sp1 sp2 "(:!:)" p a b
-    showsPrecWith2 sp1 sp2 p (a :@: b) =
-        showsInfix sp1 sp2 ":@:" p 4 a b
-    showsPrecWith2 sp1 sp2 p (TyConPlain a b) =
-        showsInfix sp1 sp2 "`TyConPlain`" p 5 a b
-
-instance Show a => Show1 (TyConGADT a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyConGADT where
-    showsPrecWith2 sp1 sp2 p (a :. b) =
-        showsInfix sp1 sp2 ":." p 1 a b
-    showsPrecWith2 sp1 sp2 p (a :.. b) =
-        showsBinaryWith sp1 sp2 "(:..)" p a b
-    showsPrecWith2 sp1 sp2 p ((:...) a b i) =
-        showsTernaryWith sp1 sp2 "(:...)" p a b i
-    showsPrecWith2 sp1 sp2 p (a :.... b) =
-        showsBinaryWith sp1 sp2 "(:....)" p a b
-
-instance Show a => Show1 (TyFamilyPlain a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyFamilyPlain where
-    showsPrecWith2 sp1 sp2 p (a :#: b) =
-        showsBinaryWith sp1 sp2 "(:#:)" p a b
-    showsPrecWith2 sp1 sp2 p (a :$: b) =
-        showsInfix sp1 sp2 ":$:" p 4 a b
-    showsPrecWith2 sp1 sp2 p (TyFamilyPlain a b) =
-        showsInfix sp1 sp2 "`TyFamilyPlain`" p 5 a b
-
-instance Show a => Show1 (TyFamilyGADT a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyFamilyGADT where
-    showsPrecWith2 sp1 sp2 p (a :* b) =
-        showsInfix sp1 sp2 ":*" p 1 a b
-    showsPrecWith2 sp1 sp2 p (a :** b) =
-        showsBinaryWith sp1 sp2 "(:**)" p a b
-    showsPrecWith2 sp1 sp2 p ((:***) a b i) =
-        showsTernaryWith sp1 sp2 "(:***)" p a b i
-    showsPrecWith2 sp1 sp2 p (a :**** b) =
-        showsBinaryWith sp1 sp2 "(:****)" p a b
-
-showsInfix :: (Int -> a -> ShowS) -> (Int -> b -> ShowS)
-           -> String -> Int -> Int -> a -> b -> ShowS
-showsInfix sp1 sp2 name p infixPrec a b = showParen (p > infixPrec) $
-      sp1 (infixPrec + 1) a . showSpace
-    . showString name       . showSpace
-    . sp2 (infixPrec + 1) b
-
-showsTernaryWith :: (Int -> a -> ShowS) -> (Int -> b -> ShowS)
-                 -> String -> Int -> a -> b -> Int -> ShowS
-showsTernaryWith sp1 sp2 name p a b i = showParen (p > appPrec) $
-      showString name . showSpace
-    . sp1 appPrec1 a  . showSpace
-    . sp2 appPrec1 b  . showSpace
-    . showsPrec appPrec1 i
-
--------------------------------------------------------------------------------
+$(deriveShow1 ''TyConPlain)
+$(deriveShow1 ''TyConGADT)
+#if defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow2 ''TyConPlain)
+$(deriveShow2 ''TyConGADT)
+#endif
 
 $(deriveTextShow  ''TyConPlain)
 $(deriveTextShow1 ''TyConPlain)
@@ -223,16 +169,6 @@ $(deriveTextShow  ''TyConGADT)
 $(deriveTextShow1 ''TyConGADT)
 $(deriveTextShow2 ''TyConGADT)
 
-#if MIN_VERSION_template_haskell(2,7,0)
-$(deriveTextShow  '(:#:))
-$(deriveTextShow1 '(:$:))
-$(deriveTextShow2 'TyFamilyPlain)
-
-$(deriveTextShow  '(:*))
-$(deriveTextShow1 '(:***))
-$(deriveTextShow2 '(:****))
-#endif
-
 #if __GLASGOW_HASKELL__ < 706
 $(Generics.deriveMeta           ''TyConPlain)
 $(Generics.deriveRepresentable1 ''TyConPlain)
@@ -244,6 +180,26 @@ $(Generics.deriveRepresentable0 ''TyConPlain)
 #endif
 
 #if MIN_VERSION_template_haskell(2,7,0)
+# if !defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow1 '(:#:))
+
+$(deriveShow1 '(:*))
+# else
+$(deriveShow1 '(:#:))
+$(deriveShow2 '(:$:))
+
+$(deriveShow1 '(:*))
+$(deriveShow2 '(:***))
+# endif
+
+$(deriveTextShow  '(:#:))
+$(deriveTextShow1 '(:$:))
+$(deriveTextShow2 'TyFamilyPlain)
+
+$(deriveTextShow  '(:*))
+$(deriveTextShow1 '(:***))
+$(deriveTextShow2 '(:****))
+
 # if !defined(__LANGUAGE_DERIVE_GENERIC1__)
 $(Generics.deriveMeta           '(:#:))
 $(Generics.deriveRepresentable1 '(:$:))
