@@ -6,9 +6,13 @@
 {-# LANGUAGE DeriveGeneric   #-}
 #endif
 
+#if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE DataKinds       #-}
+#endif
+
 {-|
 Module:      Derived.Records
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -30,19 +34,18 @@ import           GHC.Generics (Generic)
 import           GHC.Generics (Generic1)
 # endif
 #endif
-import           GHC.Show (showSpace)
-#if __GLASGOW_HASKELL__ < 711
-import           GHC.Show (appPrec)
-#endif
 
 import           Prelude ()
 import           Prelude.Compat
 
 import           Test.QuickCheck (Arbitrary(..), oneof)
 
-import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
+import           Text.Show.Deriving (deriveShow1)
+#if defined(NEW_FUNCTOR_CLASSES)
+import           Text.Show.Deriving (deriveShow2)
+#endif
 
-import           TransformersCompat (Show1(..), Show2(..))
+import           TextShow.TH (deriveTextShow, deriveTextShow1, deriveTextShow2)
 
 -------------------------------------------------------------------------------
 
@@ -60,12 +63,7 @@ data TyCon a b = TyConPrefix { tc1 :: a, tc2 :: b }
 
 -------------------------------------------------------------------------------
 
-data family TyFamily
-#if __GLASGOW_HASKELL__ >= 708 && __GLASGOW_HASKELL__ < 710
-    a b :: *
-#else
-    y z :: *
-#endif
+data family TyFamily y z :: *
 
 infixl 4 :!:
 data instance TyFamily a b = TyFamilyPrefix { tf1 :: a, tf2 :: b }
@@ -93,46 +91,15 @@ instance (Arbitrary a, Arbitrary b) => Arbitrary (TyFamily a b) where
 
 -------------------------------------------------------------------------------
 
-instance Show a => Show1 (TyCon a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyCon where
-    showsPrecWith2 sp1 sp2 p (TyConPrefix a b) =
-        showsRecord sp1 sp2 "TyConPrefix" "tc1" "tc2" p a b
-    showsPrecWith2 sp1 sp2 p (a :@: b) =
-        showsRecord sp2 sp1 "(:@:)" "tc3" "tc4" p a b
-
-instance Show a => Show1 (TyFamily a) where
-    showsPrecWith = showsPrecWith2 showsPrec
-instance Show2 TyFamily where
-    showsPrecWith2 sp1 sp2 p (TyFamilyPrefix a b) =
-        showsRecord sp1 sp2 "TyFamilyPrefix" "tf1" "tf2" p a b
-    showsPrecWith2 sp1 sp2 p (a :!: b) =
-        showsRecord sp2 sp1 "(:!:)" "tf3" "tf4" p a b
-
-showsRecord :: (Int -> a -> ShowS) -> (Int -> b -> ShowS)
-            -> String -> String -> String -> Int -> a -> b -> ShowS
-showsRecord sp1 sp2 con rec1 rec2 _p a b =
-#if __GLASGOW_HASKELL__ < 711
-    showParen (_p > appPrec) $
+$(deriveShow1 ''TyCon)
+#if defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow2 ''TyCon)
 #endif
-          showString con . showSpace
-        . showChar '{'
-        . showString rec1 . showString " = " . sp1 0 a . showString ", "
-        . showString rec2 . showString " = " . sp2 0 b
-        . showChar '}'
-
--------------------------------------------------------------------------------
 
 $(deriveTextShow  ''TyCon)
 $(deriveTextShow1 ''TyCon)
 $(deriveTextShow2 ''TyCon)
 
-#if MIN_VERSION_template_haskell(2,7,0)
-$(deriveTextShow  'TyFamilyPrefix)
-$(deriveTextShow1 '(:!:))
-$(deriveTextShow2 'TyFamilyPrefix)
-#endif
-
 #if __GLASGOW_HASKELL__ < 706
 $(Generics.deriveMeta           ''TyCon)
 $(Generics.deriveRepresentable1 ''TyCon)
@@ -143,6 +110,17 @@ $(Generics.deriveRepresentable0 ''TyCon)
 #endif
 
 #if MIN_VERSION_template_haskell(2,7,0)
+# if !defined(NEW_FUNCTOR_CLASSES)
+$(deriveShow1 'TyFamilyPrefix)
+# else
+$(deriveShow1 'TyFamilyPrefix)
+$(deriveShow2 '(:!:))
+# endif
+
+$(deriveTextShow  'TyFamilyPrefix)
+$(deriveTextShow1 '(:!:))
+$(deriveTextShow2 'TyFamilyPrefix)
+
 # if !defined(__LANGUAGE_DERIVE_GENERIC1__)
 $(Generics.deriveMeta           'TyFamilyPrefix)
 $(Generics.deriveRepresentable1 '(:!:))
