@@ -5,7 +5,7 @@
 
 {-|
 Module:      Instances.Control.Exception
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -79,6 +79,11 @@ instance Arbitrary AllocationLimitExceeded where
     arbitrary = pure AllocationLimitExceeded
 #endif
 
+#if MIN_VERSION_base(4,9,0)
+instance Arbitrary TypeError where
+    arbitrary = TypeError <$> arbitrary
+#endif
+
 instance Arbitrary Deadlock where
     arbitrary = pure Deadlock
 
