@@ -1,8 +1,12 @@
+{-# LANGUAGE CPP #-}
+
+#if !(MIN_VERSION_QuickCheck(2,9,0))
 {-# OPTIONS_GHC -fno-warn-orphans #-}
+#endif
 
 {-|
 Module:      Instances.Data.Version
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -12,6 +16,7 @@ Portability: GHC
 -}
 module Instances.Data.Version () where
 
+#if !(MIN_VERSION_QuickCheck(2,9,0))
 import Data.Version (Version(..))
 
 import Prelude ()
@@ -21,3 +26,4 @@ import Test.QuickCheck (Arbitrary(..))
 
 instance Arbitrary Version where
     arbitrary = Version <$> arbitrary <*> arbitrary
+#endif
