@@ -3,7 +3,7 @@
 
 {-|
 Module:      Instances.GHC.RTS.Flags
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -16,7 +16,9 @@ module Instances.GHC.RTS.Flags () where
 #if MIN_VERSION_base(4,8,0)
 import GHC.RTS.Flags
 import Test.QuickCheck (Arbitrary(..))
+#endif
 
+#if MIN_VERSION_base(4,8,0)
 instance Arbitrary ConcFlags where
     arbitrary = ConcFlags <$> arbitrary <*> arbitrary
 
@@ -33,3 +35,10 @@ instance Arbitrary DebugFlags where
 instance Arbitrary TickyFlags where
     arbitrary = TickyFlags <$> arbitrary <*> arbitrary
 #endif
+
+#if __GLASGOW_HASKELL__ >= 801
+instance Arbitrary ParFlags where
+    arbitrary = ParFlags <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
+                         <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
+                         <*> arbitrary <*> arbitrary
+#endif
