@@ -3,7 +3,7 @@
 
 {-|
 Module:      Instances.GHC.StaticPtr
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -18,5 +18,10 @@ import GHC.StaticPtr (StaticPtrInfo(..))
 import Test.QuickCheck (Arbitrary(..))
 
 instance Arbitrary StaticPtrInfo where
-    arbitrary = StaticPtrInfo <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
-#endif 
+    arbitrary = StaticPtrInfo <$> arbitrary
+                              <*> arbitrary
+                              <*> arbitrary
+# if __GLASGOW_HASKELL__ < 801
+                              <*> arbitrary
+# endif
+#endif
