@@ -1,6 +1,6 @@
 {-|
-Module:      Spec.Data.Functor.Identity
-Copyright:   (C) 2014-2015 Ryan Scott
+Module:      Spec.Data.Functor.IdentitySpec
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -10,7 +10,8 @@ Portability: GHC
 -}
 module Spec.Data.Functor.IdentitySpec (main, spec) where
 
-import Data.Functor.Classes ()
+import Control.Monad.Trans.Instances ()
+
 import Data.Functor.Identity (Identity)
 
 import Instances.Data.Functor.Identity ()
