@@ -1,8 +1,13 @@
+{-# LANGUAGE CPP           #-}
 {-# LANGUAGE TypeOperators #-}
 
+#if __GLASGOW_HASKELL__ >= 706
+{-# LANGUAGE DataKinds     #-}
+#endif
+
 {-|
 Module:      Spec.GHC.GenericsSpec
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -14,10 +19,16 @@ module Spec.GHC.GenericsSpec (main, spec) where
 
 import Data.Orphans ()
 
-import Generics.Deriving.Base (U1, Par1, Rec1, K1, M1, (:+:), (:*:), (:.:),
-                               UChar, UDouble, UFloat, UInt, UWord,
-                               Fixity, Associativity, Arity)
-import Generics.Deriving.Instances ()
+import Generics.Deriving.Base ( U1, Par1, Rec1, K1, M1, (:+:), (:*:), (:.:)
+                              , UChar, UDouble, UFloat, UInt, UWord
+                              , Fixity, Associativity
+#if MIN_VERSION_base(4,9,0)
+                              , Meta(MetaData), SourceUnpackedness
+                              , SourceStrictness, DecidedStrictness
+#else
+                              , Arity
+#endif
+                              )
 
 import Instances.GHC.Generics ()
 
@@ -29,6 +40,18 @@ import Test.Hspec.QuickCheck (prop)
 main :: IO ()
 main = hspec spec
 
+#if MIN_VERSION_base(4,9,0)
+type MD = 'MetaData "Example" "Module" "package" 'False
+
+m1Description :: String
+m1Description = "M1 () ('MetaData \"Example\" \"Module\" \"package\" 'False) Maybe Int"
+#else
+type MD = ()
+
+m1Description :: String
+m1Description = "M1 () () Maybe Int"
+#endif
+
 spec :: Spec
 spec = parallel $ do
     describe "Fixity" $ do
@@ -37,9 +60,21 @@ spec = parallel $ do
     describe "Associativity" $ do
         prop "TextShow instance" (prop_matchesTextShow  :: Int -> Associativity -> Bool)
         prop "generic TextShow"  (prop_genericTextShow  :: Int -> Associativity -> Bool)
+#if MIN_VERSION_base(4,9,0)
+    describe "SourceUnpackedness" $ do
+        prop "TextShow instance" (prop_matchesTextShow  :: Int -> SourceUnpackedness -> Bool)
+        prop "generic TextShow"  (prop_genericTextShow  :: Int -> SourceUnpackedness -> Bool)
+    describe "SourceStrictness" $ do
+        prop "TextShow instance" (prop_matchesTextShow  :: Int -> SourceStrictness -> Bool)
+        prop "generic TextShow"  (prop_genericTextShow  :: Int -> SourceStrictness -> Bool)
+    describe "DecidedStrictness" $ do
+        prop "TextShow instance" (prop_matchesTextShow  :: Int -> DecidedStrictness -> Bool)
+        prop "generic TextShow"  (prop_genericTextShow  :: Int -> DecidedStrictness -> Bool)
+#else
     describe "Arity" $ do
         prop "TextShow instance" (prop_matchesTextShow  :: Int -> Arity -> Bool)
         prop "generic TextShow"  (prop_genericTextShow  :: Int -> Arity -> Bool)
+#endif
     describe "U1 Int" $ do
         prop "TextShow instance" (prop_matchesTextShow  :: Int -> U1 Int -> Bool)
         prop "generic TextShow"  (prop_genericTextShow  :: Int -> U1 Int -> Bool)
@@ -52,9 +87,9 @@ spec = parallel $ do
     describe "K1 () Int ()" $ do
         prop "TextShow instance" (prop_matchesTextShow  :: Int -> K1 () Int () -> Bool)
         prop "generic TextShow"  (prop_genericTextShow  :: Int -> K1 () Int () -> Bool)
-    describe "M1 () () Maybe Int" $ do
-        prop "TextShow instance" (prop_matchesTextShow  :: Int -> M1 () () Maybe Int -> Bool)
-        prop "generic TextShow"  (prop_genericTextShow  :: Int -> M1 () () Maybe Int -> Bool)
+    describe m1Description $ do
+        prop "TextShow instance" (prop_matchesTextShow  :: Int -> M1 () MD Maybe Int -> Bool)
+        prop "generic TextShow"  (prop_genericTextShow  :: Int -> M1 () MD Maybe Int -> Bool)
     describe "(Maybe :+: Maybe) Int" $ do
         prop "TextShow instance" (prop_matchesTextShow  :: Int -> (Maybe :+: Maybe) Int -> Bool)
         prop "generic TextShow"  (prop_genericTextShow  :: Int -> (Maybe :+: Maybe) Int -> Bool)
