@@ -2,7 +2,7 @@
 
 {-|
 Module:      Spec.GHC.RTS.Flags
-Copyright:   (C) 2014-2015 Ryan Scott
+Copyright:   (C) 2014-2016 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Stability:   Provisional
@@ -53,6 +53,10 @@ spec = parallel $ do
         prop "TextShow instance" prop_showTraceFlags
     describe "TickyFlags" $
         prop "TextShow instance" (prop_matchesTextShow :: Int -> TickyFlags -> Bool)
+# if __GLASGOW_HASKELL__ >= 801
+    describe "ParFlags" $
+        prop "TextShow instance" (prop_matchesTextShow :: Int -> ParFlags -> Bool)
+# endif
 #else
     pure ()
 #endif
